summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--UnoControls/source/base/basecontrol.cxx2
-rw-r--r--basic/source/classes/sbxmod.cxx4
-rw-r--r--odk/examples/java/Storage/Test03.java6
-rw-r--r--odk/examples/java/Storage/Test06.java4
-rw-r--r--package/qa/ofopxmlstorages/Test03.java6
-rw-r--r--package/qa/ofopxmlstorages/Test06.java4
-rw-r--r--package/qa/storages/Test03.java6
-rw-r--r--package/qa/storages/Test06.java4
-rw-r--r--qadevOOo/tests/java/ifc/container/_XHierarchicalNameAccess.java4
9 files changed, 20 insertions, 20 deletions
diff --git a/UnoControls/source/base/basecontrol.cxx b/UnoControls/source/base/basecontrol.cxx
index b31dad766a58..1e072f1bb3f7 100644
--- a/UnoControls/source/base/basecontrol.cxx
+++ b/UnoControls/source/base/basecontrol.cxx
@@ -293,7 +293,7 @@ void SAL_CALL BaseControl::createPeer( const Reference< XToolkit >& xToo
m_xMultiplexer->setPeer( m_xPeerWindow );
}
- // create new referenz to xgraphics for painting on a peer
+ // create new reference to xgraphics for painting on a peer
// and add a paint listener
Reference< XDevice > xDevice( m_xPeerWindow, UNO_QUERY );
diff --git a/basic/source/classes/sbxmod.cxx b/basic/source/classes/sbxmod.cxx
index c26df9c906ee..fd6713b6eb49 100644
--- a/basic/source/classes/sbxmod.cxx
+++ b/basic/source/classes/sbxmod.cxx
@@ -1920,7 +1920,7 @@ SbMethod::SbMethod( const OUString& r, SbxDataType t, SbModule* p )
nLine2 = 0;
refStatics = new SbxArray;
mCaller = nullptr;
- // HACK due to 'Referenz could not be saved'
+ // HACK due to 'Reference could not be saved'
SetFlag( SbxFlagBits::NoModify );
}
@@ -1982,7 +1982,7 @@ bool SbMethod::LoadData( SvStream& rStrm, sal_uInt16 nVer )
nStart = nTempStart;
}
- // HACK ue to 'Referenz could not be saved'
+ // HACK due to 'Reference could not be saved'
SetFlag( SbxFlagBits::NoModify );
return true;
diff --git a/odk/examples/java/Storage/Test06.java b/odk/examples/java/Storage/Test06.java
index 74a6332ea1dc..22ff96a72221 100644
--- a/odk/examples/java/Storage/Test06.java
+++ b/odk/examples/java/Storage/Test06.java
@@ -214,7 +214,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.copyElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -229,7 +229,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.moveElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
diff --git a/package/qa/ofopxmlstorages/Test06.java b/package/qa/ofopxmlstorages/Test06.java
index 6817134d32ad..afc3fcd4a0f1 100644
--- a/package/qa/ofopxmlstorages/Test06.java
+++ b/package/qa/ofopxmlstorages/Test06.java
@@ -225,7 +225,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.copyElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -240,7 +240,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.moveElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
diff --git a/package/qa/storages/Test06.java b/package/qa/storages/Test06.java
index 26e75b51468c..2954ca1421c3 100644
--- a/package/qa/storages/Test06.java
+++ b/package/qa/storages/Test06.java
@@ -227,7 +227,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.copyElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of copying of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -242,7 +242,7 @@ public class Test06 implements StorageTest {
try
{
xTempStorage.moveElementTo( "Nonexistent element", xTargetStorage, "Target" );
- m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexisting element!" );
+ m_aTestHelper.Error( "An exception must be thrown in case of moving of nonexistent element!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
diff --git a/qadevOOo/tests/java/ifc/container/_XHierarchicalNameAccess.java b/qadevOOo/tests/java/ifc/container/_XHierarchicalNameAccess.java
index 9f0f231cb36a..b128f199de91 100644
--- a/qadevOOo/tests/java/ifc/container/_XHierarchicalNameAccess.java
+++ b/qadevOOo/tests/java/ifc/container/_XHierarchicalNameAccess.java
@@ -42,10 +42,10 @@ public class _XHierarchicalNameAccess extends MultiMethodTest{
public XHierarchicalNameAccess oObj = null;
/**
- * Calls the method with existing and nonexisting
+ * Calls the method with existing and nonexistent
* element names. <p>
* Has <b>OK</b> status if for existing name <code>true</code>
- * is returned and for nonexisting - <code>false</code>.
+ * is returned and for nonexistent - <code>false</code>.
*/
public void _hasByHierarchicalName(){
String name = (String) tEnv.getObjRelation("ElementName") ;
diff --git a/odk/examples/java/Storage/Test03.java b/odk/examples/java/Storage/Test03.java
index 51be98575b8c..500d46b923b7 100644
--- a/odk/examples/java/Storage/Test03.java
+++ b/odk/examples/java/Storage/Test03.java
@@ -90,10 +90,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
// check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
try {
xTempStorage.isStorageElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStorageElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStorageElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -107,7 +107,7 @@ public class Test03 implements StorageTest {
try {
xTempStorage.isStreamElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStreamElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStreamElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -90,10 +90,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
- // check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
+ // check that isStorageElement() and isStreamElement reacts to nonexistent object correctly
try {
xTempStorage.isStorageElement( "does not exist" );
diff --git a/package/qa/ofopxmlstorages/Test03.java b/package/qa/ofopxmlstorages/Test03.java
index 99bab1d1c79e..d2f7bfa5b3d1 100644
--- a/package/qa/ofopxmlstorages/Test03.java
+++ b/package/qa/ofopxmlstorages/Test03.java
@@ -119,10 +119,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
// check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
try {
xTempStorage.isStorageElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStorageElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStorageElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -136,7 +136,7 @@ public class Test03 implements StorageTest {
try {
xTempStorage.isStreamElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStreamElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStreamElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -119,10 +119,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
- // check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
+ // check that isStorageElement() and isStreamElement reacts to nonexistent object correctly
try {
xTempStorage.isStorageElement( "does not exist" );
diff --git a/package/qa/storages/Test03.java b/package/qa/storages/Test03.java
index 57b2f1b25315..8e7c1ee304f0 100644
--- a/package/qa/storages/Test03.java
+++ b/package/qa/storages/Test03.java
@@ -111,10 +111,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
// check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
try {
xTempStorage.isStorageElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStorageElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStorageElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -128,7 +128,7 @@ public class Test03 implements StorageTest {
try {
xTempStorage.isStreamElement( "does not exist" );
- m_aTestHelper.Error( "Nonexisting element doesn't detected by isStreamElement() call!" );
+ m_aTestHelper.Error( "Nonexistent element doesn't detected by isStreamElement() call!" );
return false;
}
catch( com.sun.star.container.NoSuchElementException ne )
@@ -111,10 +111,10 @@ public class Test03 implements StorageTest {
// check storage hierarchy tree
- // check that isStorageElement() and isStreamElement reacts to nonexisting object correctly
+ // check that isStorageElement() and isStreamElement reacts to nonexistent object correctly
try {
xTempStorage.isStorageElement( "does not exist" );